[![DL stat](https://img.shields.io/pypi/v/mypdns.png)](https://pypi.org/project/mypdns)
[![Downloads Total](https://static.pepy.tech/personalized-badge/mypdns?period=total&units=none&left_color=black&right_color=brightgreen&left_text=Downloads%20Total)](https://pepy.tech/project/mypdns)
[![Downloads Month](https://static.pepy.tech/personalized-badge/mypdns?period=month&units=none&left_color=black&right_color=brightgreen&left_text=Downloads%20Month)](https://pepy.tech/project/mypdns)
[![Downloads Week](https://static.pepy.tech/personalized-badge/mypdns?period=week&units=none&left_color=black&right_color=brightgreen&left_text=Downloads%20Week)](https://pepy.tech/project/mypdns)
[![My Privacy DNS Release](https://github.com/mypdns/mypdns/actions/workflows/master.yaml/badge.svg?branch=master)](https://github.com/mypdns/mypdns/actions/workflows/master.yaml)

Namespace Reservation for [My Privacy DNS](https://mypdns.org/) blacklist project
